@@ -1102,6 +1102,7 @@ class Path(str):
             DeprecationWarning,
             stacklevel=2,
         )
+        return self.is_dir()
 
     def is_dir(self):
         """.. seealso:: :func:`os.path.isdir`"""
@@ -1113,6 +1114,7 @@ class Path(str):
             DeprecationWarning,
             stacklevel=2,
         )
+        return self.is_file()
 
     def is_file(self):
         """.. seealso:: :func:`os.path.isfile`"""
